@@ -47,7 +47,7 @@ class CalculateResultsBase:
                                                y,
                                                predictions_mean,
                                                error_metrics,
-                                               predictions_sample=None,
+                                               predictions_sample=np.zeros((1,)),
                                                predictions_std=None):
         """Calculates the main metrics for each group
 
@@ -64,7 +64,8 @@ class CalculateResultsBase:
 
         """
         y_p = y[self.n - self.h:self.n, :]
-        predictions_sample = predictions_sample[self.n - self.h:self.n, :, :]
+        if predictions_sample.any():
+            predictions_sample = predictions_sample[self.n - self.h:self.n, :, :]
         n_s = y_p.shape[1]
         error_metrics['mase'][f'{group_name}_ind'] = np.round(self.mase(y=y,
                                                                         f=predictions_mean), 3)
@@ -117,11 +118,13 @@ class CalculateResultsBottomUp(CalculateResultsBase):
         all the information regarding the different groups
     """
 
-    def __init__(self, pred_samples, groups):
+    def __init__(self, pred_samples, groups, store_prediction_samples, store_prediction_points):
         super().__init__(groups=groups)
         self.pred_mean = np.mean(pred_samples, axis=2).reshape(self.n, self.s)[self.n - self.h:self.n, :]
         self.pred_mean_complete = np.mean(pred_samples, axis=2).reshape(self.n, self.s)
         self.pred_samples = pred_samples
+        self.store_prediction_samples = store_prediction_samples
+        self.store_prediction_points = store_prediction_points
 
     def compute_error_for_every_group(self, error_metrics):
         """Computes the error metrics for all the groups
@@ -143,16 +146,17 @@ class CalculateResultsBottomUp(CalculateResultsBase):
                 y_g[:, idx] = np.sum(idx_dict_new[name] * self.y_f, axis=1)
                 f_g[:, idx] = np.sum(idx_dict_new[name] * self.pred_mean, axis=1)
                 s_g[:, idx, :] = np.sum(idx_dict_new[name][:, :, np.newaxis] * self.pred_samples, axis=1)
-                error_metrics['predictions'][name] = f_g[:, idx]
-                error_metrics['predictions']['samples'][name] = s_g[:, idx, :]
+                if self.store_prediction_points:
+                    error_metrics['predictions']['points'][name] = f_g[:, idx]
+                if self.store_prediction_samples:
+                    error_metrics['predictions']['samples'][name] = s_g[:, idx, :]
 
             error_metrics = self.calculate_metrics_for_individual_group(group,
                                                                         y_g,
                                                                         f_g,
                                                                         error_metrics,
                                                                         predictions_sample=s_g)
-            error_metrics['predictions'][group] = np.sum(f_g, axis=1)
-            error_metrics['predictions']['samples'][group] = np.sum(s_g, axis=1)
+
         return error_metrics
 
     def bottom_up(self, level, error_metrics):
@@ -168,8 +172,10 @@ class CalculateResultsBottomUp(CalculateResultsBase):
                                                                         self.pred_mean,
                                                                         error_metrics,
                                                                         predictions_sample=self.pred_samples)
-            error_metrics['predictions']['bottom'] = self.pred_mean
-            error_metrics['predictions']['samples']['bottom'] = self.pred_samples
+            if self.store_prediction_points:
+                error_metrics['predictions']['points']['bottom'] = self.pred_mean
+            if self.store_prediction_samples:
+                error_metrics['predictions']['samples']['bottom'] = self.pred_samples
         elif level == 'total':
             error_metrics = self.calculate_metrics_for_individual_group(level,
                                                                         np.sum(self.y_f, axis=1).reshape(-1, 1),
@@ -179,8 +185,10 @@ class CalculateResultsBottomUp(CalculateResultsBase):
                                                                                                   axis=1)
                                                                         .reshape((self.n, 1, -1)))
 
-            error_metrics['predictions']['total'] = np.sum(self.pred_mean, axis=1).reshape(-1, 1)
-            error_metrics['predictions']['samples']['total'] = np.sum(self.pred_samples, axis=2)
+            if self.store_prediction_points:
+                error_metrics['predictions']['points']['total'] = np.sum(self.pred_mean, axis=1)
+            if self.store_prediction_samples:
+                error_metrics['predictions']['samples']['total'] = np.sum(self.pred_samples, axis=1)
         elif level == 'groups':
             self.compute_error_for_every_group(error_metrics)
 
@@ -198,8 +206,12 @@ class CalculateResultsBottomUp(CalculateResultsBase):
         error_metrics['mase'] = {}
         error_metrics['rmse'] = {}
         error_metrics['CRPS'] = {}
-        error_metrics['predictions'] = {}
-        error_metrics['predictions']['samples'] = {}
+        if self.store_prediction_points or self.store_prediction_samples:
+            error_metrics['predictions'] = {}
+        if self.store_prediction_points:
+            error_metrics['predictions']['points'] = {}
+        if self.store_prediction_samples:
+            error_metrics['predictions']['samples'] = {}
 
         error_metrics = self.bottom_up('bottom', error_metrics)
         error_metrics = self.bottom_up('total', error_metrics)
@@ -207,9 +219,8 @@ class CalculateResultsBottomUp(CalculateResultsBase):
 
         # Aggregate all errors and create the 'all' category
         for err in self.errs:
-            error_metrics[err]['all_ind'] = np.concatenate([error_metrics[err][f'{x}_ind'].reshape((-1, 1)) for x in
-                                                            self.levels],
-                                                           0)
+            error_metrics[err]['all_ind'] = np.squeeze(np.concatenate([error_metrics[err][f'{x}_ind'].reshape((-1, 1))
+                                                                       for x in self.levels], 0))
             error_metrics[err]['all'] = np.mean(error_metrics[err]['all_ind'])
 
         return error_metrics
@@ -230,9 +241,11 @@ class CalculateResultsMint(CalculateResultsBase):
     groups : dict
         dictionary with all the information regarding the different groups
     """
-    def __init__(self, df_results_mint, groups):
+    def __init__(self, df_results_mint, groups, store_prediction_samples, store_prediction_points):
         super().__init__(groups=groups)
         self.df_results_mint = df_results_mint
+        self.store_prediction_samples = store_prediction_samples
+        self.store_prediction_points = store_prediction_points
 
     def compute_error_for_every_group(self, error_metrics):
         """Computes the error metrics for all the groups
@@ -260,28 +273,32 @@ class CalculateResultsMint(CalculateResultsBase):
                 std_g[:, idx] = np.asarray(pred_samples_group.loc[pred_samples_group
                                            .iloc[:, :self.groups['train']['g_number']-1]
                                            .isin(['<aggregated>']).all(axis=1)]['std']).reshape((self.h,))
-                error_metrics['predictions'][name] = f_g
-                error_metrics['predictions']['samples'][name] = np.random.normal(loc=f_g,
-                                                                                 scale=std_g,
-                                                                                 size=(self.samples,
-                                                                                       self.h,
-                                                                                       self.s)).reshape((self.h,
-                                                                                                         self.s,
-                                                                                                         -1))
+                if self.store_prediction_points:
+                    error_metrics['predictions']['points'][name] = f_g
+                if self.store_prediction_samples:
+                    error_metrics['predictions']['samples'][name] = np.random.normal(loc=f_g,
+                                                                                     scale=std_g,
+                                                                                     size=(self.samples,
+                                                                                           self.h,
+                                                                                           self.s)).reshape((self.h,
+                                                                                                             self.s,
+                                                                                                             -1))
 
             error_metrics = self.calculate_metrics_for_individual_group(group,
                                                                         y_g,
                                                                         f_g,
                                                                         error_metrics,
                                                                         predictions_std=std_g)
-            error_metrics['predictions'][group] = f_g
-            error_metrics['predictions']['samples'][group] = np.random.normal(loc=f_g,
-                                                                              scale=std_g,
-                                                                              size=(self.samples,
-                                                                                    self.h,
-                                                                                    self.s)).reshape((self.h,
-                                                                                                      self.s,
-                                                                                                      -1))
+            if self.store_prediction_points:
+                error_metrics['predictions']['points'][group] = f_g
+            if self.store_prediction_samples:
+                error_metrics['predictions']['samples'][group] = np.random.normal(loc=f_g,
+                                                                                  scale=std_g,
+                                                                                  size=(self.samples,
+                                                                                        self.h,
+                                                                                        self.s)).reshape((self.h,
+                                                                                                          self.s,
+                                                                                                          -1))
         return error_metrics
 
     def mint_reconciliation(self, level, error_metrics):
@@ -302,14 +319,16 @@ class CalculateResultsMint(CalculateResultsBase):
                                                                         pred_samples_mean,
                                                                         error_metrics,
                                                                         predictions_std=pred_samples_std)
-            error_metrics['predictions']['bottom'] = pred_samples_mean
-            error_metrics['predictions']['samples']['bottom'] = np.random.normal(loc=pred_samples_mean,
-                                                                                 scale=pred_samples_std,
-                                                                                 size=(self.samples,
-                                                                                       self.h,
-                                                                                       self.s)).reshape((self.h,
-                                                                                                         n_s,
-                                                                                                         -1))
+            if self.store_prediction_points:
+                error_metrics['predictions']['points']['bottom'] = pred_samples_mean
+            if self.store_prediction_samples:
+                error_metrics['predictions']['samples']['bottom'] = np.random.normal(loc=pred_samples_mean,
+                                                                                     scale=pred_samples_std,
+                                                                                     size=(self.samples,
+                                                                                           self.h,
+                                                                                           self.s)).reshape((self.h,
+                                                                                                             n_s,
+                                                                                                             -1))
         elif level == 'total':
             n_s = 1
             pred_samples_mean = np.asarray(self.df_results_mint.loc[self.df_results_mint
@@ -324,14 +343,15 @@ class CalculateResultsMint(CalculateResultsBase):
                                                                         pred_samples_mean,
                                                                         error_metrics,
                                                                         predictions_std=pred_samples_std)
-            error_metrics['predictions']['total'] = pred_samples_mean
-            error_metrics['predictions']['samples']['total'] = np.random.normal(loc=pred_samples_mean,
-                                                                                scale=pred_samples_std,
-                                                                                size=(self.samples,
-                                                                                      self.h,
-                                                                                      n_s)).reshape((self.h,
-                                                                                                     n_s,
-                                                                                                     -1))
+            if self.store_prediction_points:
+                error_metrics['predictions']['points']['total'] = np.squeeze(pred_samples_mean)
+            if self.store_prediction_samples:
+                error_metrics['predictions']['samples']['total'] = np.random.normal(loc=pred_samples_mean,
+                                                                                    scale=pred_samples_std,
+                                                                                    size=(self.samples,
+                                                                                          self.h,
+                                                                                          n_s)).reshape((self.h,
+                                                                                                         -1))
         elif level == 'groups':
             self.compute_error_for_every_group(error_metrics)
 
@@ -349,8 +369,12 @@ class CalculateResultsMint(CalculateResultsBase):
         error_metrics['mase'] = {}
         error_metrics['rmse'] = {}
         error_metrics['CRPS'] = {}
-        error_metrics['predictions'] = {}
-        error_metrics['predictions']['samples'] = {}
+        if self.store_prediction_points or self.store_prediction_samples:
+            error_metrics['predictions'] = {}
+        if self.store_prediction_points:
+            error_metrics['predictions']['points'] = {}
+        if self.store_prediction_samples:
+            error_metrics['predictions']['samples'] = {}
 
         error_metrics = self.mint_reconciliation('bottom', error_metrics)
         error_metrics = self.mint_reconciliation('total', error_metrics)
@@ -358,9 +382,8 @@ class CalculateResultsMint(CalculateResultsBase):
 
         # Aggregate all errors and create the 'all' category
         for err in self.errs:
-            error_metrics[err]['all_ind'] = np.concatenate([error_metrics[err][f'{x}_ind'].reshape((-1, 1)) for x in
-                                                            self.levels],
-                                                           0)
+            error_metrics[err]['all_ind'] = np.squeeze(np.concatenate([error_metrics[err][f'{x}_ind'].reshape((-1, 1))
+                                                                       for x in self.levels], 0))
             error_metrics[err]['all'] = np.mean(error_metrics[err]['all_ind'])
 
         return error_metrics
